import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:jeweled/config/default_activity_settings.dart';
import 'package:jeweled/models/settings/settings_activity.dart';

part 'settings_activity_state.dart';

class ActivitySettingsCubit extends HydratedCubit<ActivitySettingsState> {
  ActivitySettingsCubit()
      : super(ActivitySettingsState(settings: ActivitySettings.createDefault()));

  void setValues({
    String? boardSize,
    String? colorsCount,
  }) {
    emit(
      ActivitySettingsState(
        settings: ActivitySettings(
          boardSize: boardSize ?? state.settings.boardSize,
          colorsCount: colorsCount ?? state.settings.colorsCount,
        ),
      ),
    );
  }

  String getParameterValue(String code) {
    switch (code) {
      case DefaultActivitySettings.parameterCodeBoardSize:
        return ActivitySettings.getBoardSizeValueFromUnsafe(state.settings.boardSize);
      case DefaultActivitySettings.parameterCodeColorsCount:
        return ActivitySettings.getColorsCountValueFromUnsafe(state.settings.colorsCount);
    }

    return '';
  }

  void setParameterValue(String code, String value) {
    final String boardSize = code == DefaultActivitySettings.parameterCodeBoardSize
        ? value
        : getParameterValue(DefaultActivitySettings.parameterCodeBoardSize);
    final String colorsCount = code == DefaultActivitySettings.parameterCodeColorsCount
        ? value
        : getParameterValue(DefaultActivitySettings.parameterCodeColorsCount);

    setValues(
      boardSize: boardSize,
      colorsCount: colorsCount,
    );
  }

  @override
  ActivitySettingsState? fromJson(Map<String, dynamic> json) {
    final String boardSize = json[DefaultActivitySettings.parameterCodeBoardSize] as String;
    final String colorsCount =
        json[DefaultActivitySettings.parameterCodeColorsCount] as String;

    return ActivitySettingsState(
      settings: ActivitySettings(
        boardSize: boardSize,
        colorsCount: colorsCount,
      ),
    );
  }

  @override
  Map<String, dynamic>? toJson(ActivitySettingsState state) {
    return <String, dynamic>{
      DefaultActivitySettings.parameterCodeBoardSize: state.settings.boardSize,
      DefaultActivitySettings.parameterCodeColorsCount: state.settings.colorsCount,
    };
  }
}
